diff --git a/.editorconfig b/.editorconfig
index 75c2fe61f4886762396871469bba8684f282add2..43c7138733277a83ffc7e788e0283df17f6ccf71 100644
--- a/.editorconfig
+++ b/.editorconfig
@@ -8,7 +8,7 @@ trim_trailing_whitespace = true
 indent_size = 4
 indent_style = space
 
-[*.{md,yml,yaml,html,css,scss,js,cff}]
+[*.{md,yml,yaml,html,css,scss,js}]
 indent_size = 2
 
 # These files are edited and tested upstream in nf-core/modules
diff --git a/.github/ISSUE_TEMPLATE/bug_report.yml b/.github/ISSUE_TEMPLATE/bug_report.yml
index e405327c328cc2a94ebadf33e9ac4cad766f7461..eb120e620804963a925960001d73a8e3bd777e8e 100644
--- a/.github/ISSUE_TEMPLATE/bug_report.yml
+++ b/.github/ISSUE_TEMPLATE/bug_report.yml
@@ -45,6 +45,6 @@ body:
         * Nextflow version _(eg. 22.10.1)_
         * Hardware _(eg. HPC, Desktop, Cloud)_
         * Executor _(eg. slurm, local, awsbatch)_
-        * Container engine: _(e.g. Docker, Singularity, Conda, Podman, Shifter or Charliecloud)_
+        * Container engine: _(e.g. Docker, Singularity, Conda, Podman, Shifter, Charliecloud, or Apptainer)_
         * OS _(eg. CentOS Linux, macOS, Linux Mint)_
         * Version of nf-core/hic _(eg. 1.1, 1.5, 1.8.2)_
diff --git a/.github/PULL_REQUEST_TEMPLATE.md b/.github/PULL_REQUEST_TEMPLATE.md
index c67458d182e840707cbccc6914ff1e3d95331b0e..e2cdeccdb74daad910d876e4ed48f987e3b6c2a4 100644
--- a/.github/PULL_REQUEST_TEMPLATE.md
+++ b/.github/PULL_REQUEST_TEMPLATE.md
@@ -15,7 +15,8 @@ Learn more about contributing: [CONTRIBUTING.md](https://github.com/nf-core/hic/
 
 - [ ] This comment contains a description of changes (with reason).
 - [ ] If you've fixed a bug or added code that should be tested, add tests!
-- [ ] If you've added a new tool - have you followed the pipeline conventions in the [contribution docs](https://github.com/nf-core/hic/tree/master/.github/CONTRIBUTING.md)- [ ] If necessary, also make a PR on the nf-core/hic _branch_ on the [nf-core/test-datasets](https://github.com/nf-core/test-datasets) repository.
+- [ ] If you've added a new tool - have you followed the pipeline conventions in the [contribution docs](https://github.com/nf-core/hic/tree/master/.github/CONTRIBUTING.md)
+- [ ] If necessary, also make a PR on the nf-core/hic _branch_ on the [nf-core/test-datasets](https://github.com/nf-core/test-datasets) repository.
 - [ ] Make sure your code lints (`nf-core lint`).
 - [ ] Ensure the test suite passes (`nextflow run . -profile test,docker --outdir <OUTDIR>`).
 - [ ] Usage Documentation in `docs/usage.md` is updated.
diff --git a/.github/workflows/awsfulltest.yml b/.github/workflows/awsfulltest.yml
index ad7e2ddfdff0e494d19ce8baa49db8123d6728a6..2b99a42b8738de2bf1f214c5f3d267915b5178ac 100644
--- a/.github/workflows/awsfulltest.yml
+++ b/.github/workflows/awsfulltest.yml
@@ -24,7 +24,7 @@ jobs:
             {
               "outdir": "s3://${{ secrets.AWS_S3_BUCKET }}/hic/results-${{ github.sha }}"
             }
-          profiles: test_full,aws_tower
+          profiles: test_full,public_aws_ecr
       - uses: actions/upload-artifact@v3
         with:
           name: Tower debug log file
diff --git a/.github/workflows/awstest.yml b/.github/workflows/awstest.yml
index 3f9b365ffe5729722f94316715fe5e654860c152..23c4973be1dea45f100e25c3f1b66486274b7f56 100644
--- a/.github/workflows/awstest.yml
+++ b/.github/workflows/awstest.yml
@@ -12,7 +12,7 @@ jobs:
     steps:
       # Launch workflow using Tower CLI tool action
       - name: Launch workflow via tower
-        uses: nf-core/tower-action@v3
+        uses: seqeralabs/action-tower-launch@v1
         with:
           workspace_id: ${{ secrets.TOWER_WORKSPACE_ID }}
           access_token: ${{ secrets.TOWER_ACCESS_TOKEN }}
@@ -22,7 +22,7 @@ jobs:
             {
               "outdir": "s3://${{ secrets.AWS_S3_BUCKET }}/hic/results-test-${{ github.sha }}"
             }
-          profiles: test,aws_tower
+          profiles: test,public_aws_ecr
       - uses: actions/upload-artifact@v3
         with:
           name: Tower debug log file
diff --git a/.github/workflows/branch.yml b/.github/workflows/branch.yml
index b92e3d24195d72e7a4c39605fd29de3cf657bd06..edf46df1d97b83fde71552d4d7bec5577962f318 100644
--- a/.github/workflows/branch.yml
+++ b/.github/workflows/branch.yml
@@ -13,7 +13,7 @@ jobs:
       - name: Check PRs
         if: github.repository == 'nf-core/hic'
         run: |
-          { [[ ${{github.event.pull_request.head.repo.full_name }} == nf-core/hic ]] && [[ $GITHUB_HEAD_REF = "dev" ]]; } || [[ $GITHUB_HEAD_REF == "patch" ]]
+          { [[ ${{github.event.pull_request.head.repo.full_name }} == nf-core/hic ]] && [[ $GITHUB_HEAD_REF == "dev" ]]; } || [[ $GITHUB_HEAD_REF == "patch" ]]
 
       # If the above check failed, post a comment on the PR explaining the failure
       # NOTE - this doesn't currently work if the PR is coming from a fork, due to limitations in GitHub actions secrets
diff --git a/.github/workflows/ci.yml b/.github/workflows/ci.yml
index 5531e307166fc8f4d5717ba3efc646693560c67b..83b111b5d502d72f175c685c5af89e786a53b320 100644
--- a/.github/workflows/ci.yml
+++ b/.github/workflows/ci.yml
@@ -31,7 +31,7 @@ jobs:
         uses: actions/checkout@v3
 
       - name: Install Nextflow
-        uses: nf-core/setup-nextflow@v1
+        uses: nf-core/setup-nextflow@v1.3.0
         with:
           version: "${{ matrix.NXF_VER }}"
 
diff --git a/.github/workflows/clean-up.yml b/.github/workflows/clean-up.yml
new file mode 100644
index 0000000000000000000000000000000000000000..694e90ecb1c9135ea3d776cc01b197755c1aa040
--- /dev/null
+++ b/.github/workflows/clean-up.yml
@@ -0,0 +1,24 @@
+name: "Close user-tagged issues and PRs"
+on:
+  schedule:
+    - cron: "0 0 * * 0" # Once a week
+
+jobs:
+  clean-up:
+    runs-on: ubuntu-latest
+    permissions:
+      issues: write
+      pull-requests: write
+    steps:
+      - uses: actions/stale@v7
+        with:
+          stale-issue-message: "This issue has been tagged as awaiting-changes or awaiting-feedback by an nf-core contributor. Remove stale label or add a comment otherwise this issue will be closed in 20 days."
+          stale-pr-message: "This PR has been tagged as awaiting-changes or awaiting-feedback by an nf-core contributor. Remove stale label or add a comment if it is still useful."
+          close-issue-message: "This issue was closed because it has been tagged as awaiting-changes or awaiting-feedback by an nf-core contributor and then staled for 20 days with no activity."
+          days-before-stale: 30
+          days-before-close: 20
+          days-before-pr-close: -1
+          any-of-labels: "awaiting-changes,awaiting-feedback"
+          exempt-issue-labels: "WIP"
+          exempt-pr-labels: "WIP"
+          repo-token: "${{ secrets.GITHUB_TOKEN }}"
diff --git a/.github/workflows/linting.yml b/.github/workflows/linting.yml
index 858d622efc884fba438eb48c80d4122443dfa3a0..888cb4bc35cedc7a372ba1056495d9ee7a4a4bb7 100644
--- a/.github/workflows/linting.yml
+++ b/.github/workflows/linting.yml
@@ -78,7 +78,7 @@ jobs:
 
       - uses: actions/setup-python@v4
         with:
-          python-version: "3.7"
+          python-version: "3.8"
           architecture: "x64"
 
       - name: Install dependencies
diff --git a/.pre-commit-config.yaml b/.pre-commit-config.yaml
new file mode 100644
index 0000000000000000000000000000000000000000..0c31cdb99ffe569deddbf0ef78e9e5962073d158
--- /dev/null
+++ b/.pre-commit-config.yaml
@@ -0,0 +1,5 @@
+repos:
+  - repo: https://github.com/pre-commit/mirrors-prettier
+    rev: "v2.7.1"
+    hooks:
+      - id: prettier
diff --git a/CHANGELOG.md b/CHANGELOG.md
index c111c7fb1930ea9ce19d66cfdd137b4f4b8417c0..8a9b96776378c8e5547f032fa7bec109c37bc37b 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -3,6 +3,14 @@
 The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
 and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
 
+## v2.1.0 - 2023-06-01
+
+### `Added`
+
+- Added public_aws_ecr profile for using containers stored on ECR.
+
+### `Fixed`
+
 ## v2.0.0 - 2023-01-12
 
 ### `Added`
diff --git a/README.md b/README.md
index 973e1321c8c96f11bf6c704ca4372aea401cb8ac..df0a41991f3629fae502e434a2bdfbc46e115e57 100644
--- a/README.md
+++ b/README.md
@@ -8,7 +8,7 @@
 [![run with singularity](https://img.shields.io/badge/run%20with-singularity-1d355c.svg?labelColor=000000)](https://sylabs.io/docs/)
 [![Launch on Nextflow Tower](https://img.shields.io/badge/Launch%20%F0%9F%9A%80-Nextflow%20Tower-%234256e7)](https://tower.nf/launch?pipeline=https://github.com/nf-core/hic)
 
-[![Get help on Slack](http://img.shields.io/badge/slack-nf--core%20%23hic-4A154B?labelColor=000000&logo=slack)](https://nfcore.slack.com/channels/hic)[![Follow on Twitter](http://img.shields.io/badge/twitter-%40nf__core-1DA1F2?labelColor=000000&logo=twitter)](https://twitter.com/nf_core)[![Watch on YouTube](http://img.shields.io/badge/youtube-nf--core-FF0000?labelColor=000000&logo=youtube)](https://www.youtube.com/c/nf-core)
+[![Get help on Slack](http://img.shields.io/badge/slack-nf--core%20%23hic-4A154B?labelColor=000000&logo=slack)](https://nfcore.slack.com/channels/hic)[![Follow on Twitter](http://img.shields.io/badge/twitter-%40nf__core-1DA1F2?labelColor=000000&logo=twitter)](https://twitter.com/nf_core)[![Follow on Mastodon](https://img.shields.io/badge/mastodon-nf__core-6364ff?labelColor=FFFFFF&logo=mastodon)](https://mstdn.science/@nf_core)[![Watch on YouTube](http://img.shields.io/badge/youtube-nf--core-FF0000?labelColor=000000&logo=youtube)](https://www.youtube.com/c/nf-core)
 
 ## Introduction
 
@@ -36,34 +36,45 @@ On release, automated continuous integration tests run the pipeline on a full-si
 8. TADs calling ([`HiCExplorer`](https://github.com/deeptools/HiCExplorer), [`cooltools`](https://cooltools.readthedocs.io/en/latest/))
 9. Quality control report ([`MultiQC`](https://multiqc.info/))
 
-## Quick Start
+## Usage
 
-1. Install [`Nextflow`](https://www.nextflow.io/docs/latest/getstarted.html#installation) (`>=22.10.1`)
+> **Note**
+> If you are new to Nextflow and nf-core, please refer to [this page](https://nf-co.re/docs/usage/installation) on how
+> to set-up Nextflow. Make sure to [test your setup](https://nf-co.re/docs/usage/introduction#how-to-run-a-pipeline)
+> with `-profile test` before running the workflow on actual data.
 
-2. Install any of [`Docker`](https://docs.docker.com/engine/installation/), [`Singularity`](https://www.sylabs.io/guides/3.0/user-guide/) (you can follow [this tutorial](https://singularity-tutorial.github.io/01-installation/)), [`Podman`](https://podman.io/), [`Shifter`](https://nersc.gitlab.io/development/shifter/how-to-use/) or [`Charliecloud`](https://hpc.github.io/charliecloud/) for full pipeline reproducibility _(you can use [`Conda`](https://conda.io/miniconda.html) both to install Nextflow itself and also to manage software within pipelines. Please only use it within pipelines as a last resort; see [docs](https://nf-co.re/usage/configuration#basic-configuration-profiles))_.
+First, prepare a samplesheet with your input data that looks as follows:
 
-3. Download the pipeline and test it on a minimal dataset with a single command:
+`samplesheet.csv`:
 
-   ```bash
-   nextflow run nf-core/hic -profile test,YOURPROFILE --outdir <OUTDIR>
-   ```
+```csv
+sample,fastq_1,fastq_2
+HIC_ES_4,SRR5339783_1.fastq.gz,SRR5339783_2.fastq.gz
+```
 
-   Note that some form of configuration will be needed so that Nextflow knows how to fetch the required software. This is usually done in the form of a config profile (`YOURPROFILE` in the example command above). You can chain multiple config profiles in a comma-separated string.
+Each row represents a pair of fastq files (paired end).
+Now, you can run the pipeline using:
 
-   > - The pipeline comes with config profiles called `docker`, `singularity`, `podman`, `shifter`, `charliecloud` and `conda` which instruct the pipeline to use the named tool for software management. For example, `-profile test,docker`.
-   > - Please check [nf-core/configs](https://github.com/nf-core/configs#documentation) to see if a custom config file to run nf-core pipelines already exists for your Institute. If so, you can simply use `-profile <institute>` in your command. This will enable either `docker` or `singularity` and set the appropriate execution settings for your local compute environment.
-   > - If you are using `singularity`, please use the [`nf-core download`](https://nf-co.re/tools/#downloading-pipelines-for-offline-use) command to download images first, before running the pipeline. Setting the [`NXF_SINGULARITY_CACHEDIR` or `singularity.cacheDir`](https://www.nextflow.io/docs/latest/singularity.html?#singularity-docker-hub) Nextflow options enables you to store and re-use the images from a central location for future pipeline runs.
-   > - If you are using `conda`, it is highly recommended to use the [`NXF_CONDA_CACHEDIR` or `conda.cacheDir`](https://www.nextflow.io/docs/latest/conda.html) settings to store the environments in a central location for future pipeline runs.
+```bash
+nextflow run nf-core/hic \
+   -profile <docker/singularity/.../institute> \
+   --input samplesheet.csv \
+   --genome GRCh37 \
+   --outdir <OUTDIR>
+```
 
-4. Start running your own analysis!
+> **Warning:**
+> Please provide pipeline parameters via the CLI or Nextflow `-params-file` option. Custom config files including those
+> provided by the `-c` Nextflow option can be used to provide any configuration _**except for parameters**_;
+> see [docs](https://nf-co.re/usage/configuration#custom-configuration-files).
 
-   ```bash
-   nextflow run nf-core/hic --input samplesheet.csv --outdir <OUTDIR> --genome GRCh37 -profile <docker/singularity/podman/shifter/charliecloud/conda/institute>
-   ```
+For more details, please refer to the [usage documentation](https://nf-co.re/hic/usage) and the [parameter documentation](https://nf-co.re/hic/parameters).
 
-## Documentation
+## Pipeline output
 
-The nf-core/hic pipeline comes with documentation about the pipeline [usage](https://nf-co.re/hic/usage), [parameters](https://nf-co.re/hic/parameters) and [output](https://nf-co.re/hic/output).
+To see the the results of a test run with a full size dataset refer to the [results](https://nf-co.re/hic/results) tab on the nf-core website pipeline page.
+For more details about the output files and reports, please refer to the
+[output documentation](https://nf-co.re/hic/output).
 
 ## Credits
 
diff --git a/bin/check_samplesheet.py b/bin/check_samplesheet.py
index c498ef45ee96e33a8d4f81b0be948028c712db61..dde3baaa26969f03313e3d6070633770def3c738 100755
--- a/bin/check_samplesheet.py
+++ b/bin/check_samplesheet.py
@@ -157,9 +157,6 @@ def sniff_format(handle):
     peek = read_head(handle)
     handle.seek(0)
     sniffer = csv.Sniffer()
-    if not sniffer.has_header(peek):
-        logger.critical("The given sample sheet does not appear to contain a header.")
-        sys.exit(1)
     dialect = sniffer.sniff(peek)
     return dialect
 
diff --git a/bin/mapped_2hic_dnase.py b/bin/mapped_2hic_dnase.py
index ff593666f03c5b82928ced06b941be296d6169ea..c417907a4483bd33bc6a6e0ceeb752d5c3d32121 100755
--- a/bin/mapped_2hic_dnase.py
+++ b/bin/mapped_2hic_dnase.py
@@ -362,7 +362,6 @@ if __name__ == "__main__":
 
             if cur_handler is not None:
                 if not r1.is_unmapped and not r2.is_unmapped:
-
                     ##reorient reads to ease duplicates removal
                     or1, or2 = get_ordered_reads(r1, r2)
                     or1_chrom = samfile.get_reference_name(or1.reference_id)
diff --git a/bin/mapped_2hic_fragments.py b/bin/mapped_2hic_fragments.py
index cc0e40b472dfb764ba1bf2f550c00c79bce7bd3f..a1298716ce83c4e99931534357c03634fd5d8301 100755
--- a/bin/mapped_2hic_fragments.py
+++ b/bin/mapped_2hic_fragments.py
@@ -619,7 +619,6 @@ if __name__ == "__main__":
                 r2_chrom = None
 
             if r1_resfrag is not None or r2_resfrag is not None:
-
                 interactionType = get_interaction_type(r1, r1_chrom, r1_resfrag, r2, r2_chrom, r2_resfrag, verbose)
                 dist = get_PE_fragment_size(r1, r2, r1_resfrag, r2_resfrag, interactionType)
                 cdist = get_cis_dist(r1, r2)
diff --git a/bin/mergeSAM.py b/bin/mergeSAM.py
index 82ab8c34d979240d12de57b1f2510a54a79d2ca9..d670ec2c6a94b89035ab417b4146806099c2c5aa 100755
--- a/bin/mergeSAM.py
+++ b/bin/mergeSAM.py
@@ -71,7 +71,6 @@ def get_read_name(read):
 
 
 def sam_flag(read1, read2, hr1, hr2):
-
     f1 = read1.flag
     f2 = read2.flag
 
diff --git a/conf/base.config b/conf/base.config
index 6808dbe2205a3cbe53975d4d2d2ec2fbc1998ec7..2558cb1be3b55fa76fac6e98671f945093579d44 100644
--- a/conf/base.config
+++ b/conf/base.config
@@ -14,7 +14,7 @@ process {
     memory = { check_max( 8.GB * task.attempt, 'memory' ) }
     time   = { check_max( 12.h  * task.attempt, 'time'   ) }
 
-    errorStrategy = { task.exitStatus in [143,137,104,134,139] ? 'retry' : 'finish' }
+    errorStrategy = { task.exitStatus in ((130..145) + 104) ? 'retry' : 'finish' }
     maxRetries    = 1
     maxErrors     = '-1'
 
diff --git a/conf/igenomes.config b/conf/igenomes.config
index 8b49d0827c7f45bb7f874427d7210c7f1eda3421..f4c32e3ac16734e10fe6da91f4467b0cbb39198e 100644
--- a/conf/igenomes.config
+++ b/conf/igenomes.config
@@ -19,6 +19,14 @@ params {
             fasta       = "${params.igenomes_base}/Homo_sapiens/NCBI/GRCh38/Sequence/WholeGenomeFasta/genome.fa"
             bowtie2     = "${params.igenomes_base}/Homo_sapiens/NCBI/GRCh38/Sequence/Bowtie2Index/"
         }
+        'CHM13' {
+            fasta       = "${params.igenomes_base}/Homo_sapiens/UCSC/CHM13/Sequence/WholeGenomeFasta/genome.fa"
+            bwa         = "${params.igenomes_base}/Homo_sapiens/UCSC/CHM13/Sequence/BWAIndex/"
+            bwamem2     = "${params.igenomes_base}/Homo_sapiens/UCSC/CHM13/Sequence/BWAmem2Index/"
+            gtf         = "${params.igenomes_base}/Homo_sapiens/NCBI/CHM13/Annotation/Genes/genes.gtf"
+            gff         = "ftp://ftp.ncbi.nlm.nih.gov/genomes/all/GCF/009/914/755/GCF_009914755.1_T2T-CHM13v2.0/GCF_009914755.1_T2T-CHM13v2.0_genomic.gff.gz"
+            mito_name   = "chrM"
+        }
         'GRCm38' {
             fasta       = "${params.igenomes_base}/Mus_musculus/Ensembl/GRCm38/Sequence/WholeGenomeFasta/genome.fa"
             bowtie2     = "${params.igenomes_base}/Mus_musculus/Ensembl/GRCm38/Sequence/Bowtie2Index/"
diff --git a/conf/public_aws_ecr.config b/conf/public_aws_ecr.config
new file mode 100644
index 0000000000000000000000000000000000000000..abff277b633ed64d5ab3ec9489e97c711f33fb37
--- /dev/null
+++ b/conf/public_aws_ecr.config
@@ -0,0 +1,57 @@
+/*
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    AWS ECR Config
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    Config to set public AWS ECR images wherever possible
+    This improves speed when running on AWS infrastructure.
+    Use this as an example template when using your own private registry.
+----------------------------------------------------------------------------------------
+*/
+
+docker.registry = 'public.ecr.aws'
+podman.registry = 'public.ecr.aws'
+
+process {
+    withName: 'BOWTIE2_ALIGN' {
+        container = 'quay.io/biocontainers/mulled-v2-ac74a7f02cebcfcc07d8e8d1d750af9c83b4d45a:a0ffedb52808e102887f6ce600d092675bf3528a-0'
+    }
+    withName: 'BOWTIE2_ALIGN_TRIMMED' {
+        container = 'quay.io/biocontainers/mulled-v2-ac74a7f02cebcfcc07d8e8d1d750af9c83b4d45a:a0ffedb52808e102887f6ce600d092675bf3528a-0'
+    }
+    withName: 'BUILD_CONTACT_MAPS' {
+        container = 'quay.io/nf-core/ubuntu:20.04'
+    }
+    withName: 'COMBINE_MATES' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'COOLTOOLS_EIGSCIS' {
+        container = 'quay.io/biocontainers/mulled-v2-c81d8d6b6acf4714ffaae1a274527a41958443f6:cc7ea58b8cefc76bed985dcfe261cb276ed9e0cf-0'
+    }
+    withName: 'GET_RESTRICTION_FRAGMENTS' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'GET_VALID_INTERACTION' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'GET_VALID_INTERACTION_DNASE' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'ICE_NORMALIZATION' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'MERGE_STATS' {
+        container = 'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'
+    }
+    withName: 'MERGE_VALID_INTERACTION' {
+        container = 'quay.io/nf-core/ubuntu:20.04'
+    }
+    withName: 'SAMPLESHEET_CHECK' {
+        container = 'quay.io/biocontainers/python:3.8.3'
+    }
+    withName: 'SPLIT_COOLER_DUMP' {
+        container = 'quay.io/nf-core/ubuntu:20.04'
+    }
+    withName: 'TRIM_READS' {
+        container = 'quay.io/nf-core/ubuntu:20.04'
+    }
+}
diff --git a/docs/output.md b/docs/output.md
index 9f6f7033efa9e7f87d190d5a6c1bdb548eeff9e9..1086b0371c3be007b813fdd582e5e79dde1000f6 100644
--- a/docs/output.md
+++ b/docs/output.md
@@ -23,7 +23,7 @@ The pipeline is built using [Nextflow](https://www.nextflow.io/) and processes d
 - [MultiQC](#multiqc) - aggregate report and quality controls, describing
   results of the whole pipeline
 - [Export](#exprot) - additionnal export for compatibility with downstream
-  analysis tool and visualization
+  analysis tool and visualisation
 
 ## From raw data to valid pairs
 
@@ -36,7 +36,7 @@ For details about the workflow, see
 
 #### Reads alignment
 
-Using Hi-C data, each reads mate has to be independantly aligned on the
+Using Hi-C data, each reads mate has to be independently aligned on the
 reference genome.
 The current workflow implements a two steps mapping strategy. First, the reads
 are aligned using an end-to-end aligner.
@@ -63,7 +63,7 @@ are available ;
 - `*.mapstat` - mapping statistics per read mate
 
 Usually, a high fraction of reads is expected to be aligned on the genome
-(80-90%). Among them, we usually observed a few percent (around 10%) of step 2
+(80-90%). Among them, we usually observe a few percent (around 10%) of step 2
 aligned reads. Those reads are chimeric fragments for which we detect a
 ligation junction. An abnormal level of chimeric reads can reflect a ligation
 issue during the library preparation.
@@ -142,9 +142,9 @@ removed (see `--keep_dups` to disable duplicates filtering).
 
 Additional quality controls such as fragment size distribution can be extracted
 from the list of valid interaction products.
-We usually expect to see a distribution centered around 300 pb which correspond
+We usually expect to see a distribution centered around 300 bp which corresponds
 to the paired-end insert size commonly used.
-The fraction of dplicates is also presented. A high level of duplication
+The fraction of duplicates is also presented. A high level of duplication
 indicates a poor molecular complexity and a potential PCR bias.
 Finally, an important metric is to look at the fraction of intra and
 inter-chromosomal interactions, as well as long range (>20kb) versus short
@@ -176,15 +176,15 @@ All results are available in `results/hicpro/stats`.
 
 #### Contact maps
 
-Intra et inter-chromosomal contact maps are build for all specified resolutions.
-The genome is splitted into bins of equal size. Each valid interaction is
+Intra and inter-chromosomal contact maps are built for all specified resolutions.
+The genome is split into bins of equal size. Each valid interaction is
 associated with the genomic bins to generate the raw maps.
 In addition, Hi-C data can contain several sources of biases which has to be
 corrected.
 The HiC-Pro workflow uses the [ìced](https://github.com/hiclib/iced) and
 [Varoquaux and Servant, 2018](http://joss.theoj.org/papers/10.21105/joss.01286)
 python package which proposes a fast implementation of the original ICE
-normalization algorithm (Imakaev et al. 2012), making the assumption of equal
+normalisation algorithm (Imakaev et al. 2012), making the assumption of equal
 visibility of each fragment.
 
 Importantly, the HiC-Pro maps are generated only if the `--hicpro_maps` option
@@ -221,16 +221,16 @@ downstream analysis.
 ## Hi-C contact maps
 
 Contact maps are usually stored as simple txt (`HiC-Pro`), .hic (`Juicer/Juicebox`) and .(m)cool (`cooler/Higlass`) formats.
-The .cool and .hic format are compressed and indexed and usually much more efficient that the txt format.  
-In the current workflow, we propose to use the `cooler` format as a standard to build the raw and normalized maps
-after valid pairs detection as it is used by several downstream analysis and visualization tools.
+The .cool and .hic format are compressed and indexed and usually much more efficient than the txt format.  
+In the current workflow, we propose to use the `cooler` format as a standard to build the raw and normalised maps
+after valid pairs detection as it is used by several downstream analysis and visualisation tools.
 
 Raw contact maps are therefore in **`results/contact_maps/raw`** which contains the different maps in `txt` and `cool` formats, at various resolutions.
-Normalized contact maps are stored in **`results/contact_maps/norm`** which contains the different maps in `txt`, `cool`, and `mcool` format.
+Normalised contact maps are stored in **`results/contact_maps/norm`** which contains the different maps in `txt`, `cool`, and `mcool` format.
 The bin coordinates used for all resolutions are available in **`results/contact_maps/bins`**.
 
 Note that `txt` contact maps generated with `cooler` are identical to those generated by `HiC-Pro`.
-However, differences can be observed on the normalized contact maps as the balancing algorithm is not exactly the same.
+However, differences can be observed on the normalised contact maps as the balancing algorithm is not exactly the same.
 
 ## Downstream analysis
 
@@ -246,23 +246,23 @@ The results generated with the `HiCExplorer hicPlotDistVsCounts` tool (plot and
 ### Compartments calling
 
 Compartments calling is one of the most common analysis which aims at detecting A (open, active) / B (close, inactive) compartments.
-In the first studies on the subject, the compartments were called at high/medium resolution (1000000 to 250000) which is enough to call A/B comparments.
+In the first studies on the subject, the compartments were called at high/medium resolution (1000000 to 250000) which is enough to call A/B compartments.
 Analysis at higher resolution has shown that these two main types of compartments can be further divided into compartments subtypes.
 
-Although different methods have been proposed for compartment calling, the standard remains the eigen vector decomposition from the normalized correlation maps.
+Although different methods have been proposed for compartment calling, the standard remains the eigen vector decomposition from the normalised correlation maps.
 Here, we use the implementation available in the [`cooltools`](https://cooltools.readthedocs.io/en/lates) package.
 
-Results are available in **`results/compartments/`** folder and includes :
+Results are available in **`results/compartments/`** folder and include :
 
 - `*cis.vecs.tsv`: eigenvectors decomposition along the genome
 - `*cis.lam.txt`: eigenvalues associated with the eigenvectors
 
 ### TADs calling
 
-TADs has been described as functional units of the genome.
-While contacts between genes and regulatority elements can occur within a single TADs, contacts between TADs are much less frequent, mainly due to the presence of insulation protein (such as CTCF) at their boundaries. Looking at Hi-C maps, TADs look like triangles around the diagonal. According to the contact map resolutions, TADs appear as hierarchical structures with a median size around 1Mb (in mammals), as well as smaller structures usually called sub-TADs of smaller size.
+TADs have been described as functional units of the genome.
+While contacts between genes and regulatority elements can occur within a single TAD, contacts between TADs are much less frequent, mainly due to the presence of an insulation protein (such as CTCF) at their boundaries. Looking at Hi-C maps, TADs look like triangles around the diagonal. According to the contact map resolutions, TADs appear as hierarchical structures with a median size around 1Mb (in mammals), as well as smaller structures usually called sub-TADs of smaller size.
 
-TADs calling remains a challenging task, and even if many methods have been proposed in the last decade, little overlap have been found between their results.
+TADs calling remains a challenging task, and even if many methods have been proposed in the last decade, little overlap has been found between their results.
 
 Currently, the pipeline proposes two approaches :
 
@@ -283,7 +283,7 @@ Usually, TADs results are presented as simple BED files, or bigWig files, with t
 
 </details>
 
-[MultiQC](http://multiqc.info) is a visualization tool that generates a single HTML report summarising all samples in your project. Most of the pipeline QC results are visualised in the report and further statistics are available in the report data directory.
+[MultiQC](http://multiqc.info) is a visualisation tool that generates a single HTML report summarising all samples in your project. Most of the pipeline QC results are visualised in the report and further statistics are available in the report data directory.
 
 Results generated by MultiQC collate pipeline QC from supported tools e.g. FastQC. The pipeline has special steps which also allow the software versions to be reported in the MultiQC output for future traceability. For more information about how to use MultiQC reports, see <http://multiqc.info>.
 
diff --git a/docs/usage.md b/docs/usage.md
index 961766cbf434073443c9147dd4afee2ef8aa6fcb..4ad48da5087a541195d98f097c625aa22b5a6062 100644
--- a/docs/usage.md
+++ b/docs/usage.md
@@ -64,6 +64,29 @@ work                # Directory containing the nextflow working files
 # Other nextflow hidden files, eg. history of pipeline runs and old logs.
 ```
 
+If you wish to repeatedly use the same parameters for multiple runs, rather than specifying each flag in the command, you can specify these in a params file.
+
+Pipeline settings can be provided in a `yaml` or `json` file via `-params-file <file>`.
+
+> ⚠️ Do not use `-c <file>` to specify parameters as this will result in errors. Custom config files specified with `-c` must only be used for [tuning process resource specifications](https://nf-co.re/docs/usage/configuration#tuning-workflow-resources), other infrastructural tweaks (such as output directories), or module arguments (args).
+> The above pipeline run specified with a params file in yaml format:
+
+```bash
+nextflow run nf-core/hic -profile docker -params-file params.yaml
+```
+
+with `params.yaml` containing:
+
+```yaml
+input: './samplesheet.csv'
+outdir: './results/'
+genome: 'GRCh37'
+input: 'data'
+<...>
+```
+
+You can also generate such `YAML`/`JSON` files via [nf-core/launch](https://nf-co.re/launch).
+
 ### Updating the pipeline
 
 When you run the above command, Nextflow automatically pulls the pipeline code from GitHub and stores it as a cached version. When running the pipeline after this, it will always use the cached version if available - even if the pipeline has been updated since. To make sure that you're running the latest version of the pipeline, make sure that you regularly update the cached version of the pipeline:
@@ -80,6 +103,10 @@ First, go to the [nf-core/hic releases page](https://github.com/nf-core/hic/rele
 
 This version number will be logged in reports when you run the pipeline, so that you'll know what you used when you look back in the future. For example, at the bottom of the MultiQC reports.
 
+To further assist in reproducbility, you can use share and re-use [parameter files](#running-the-pipeline) to repeat pipeline runs with the same settings without having to write out a command with every single parameter.
+
+> 💡 If you wish to share such profile (such as upload as supplementary material for academic publications), make sure to NOT include cluster specific paths to files, nor institutional specific profiles.
+
 ## Core Nextflow arguments
 
 > **NB:** These options are part of Nextflow and use a _single_ hyphen
@@ -90,7 +117,7 @@ This version number will be logged in reports when you run the pipeline, so that
 Use this parameter to choose a configuration profile. Profiles can give
 configuration presets for different compute environments.
 
-Several generic profiles are bundled with the pipeline which instruct the pipeline to use software packaged using different methods (Docker, Singularity, Podman, Shifter, Charliecloud, Conda) - see below.
+Several generic profiles are bundled with the pipeline which instruct the pipeline to use software packaged using different methods (Docker, Singularity, Podman, Shifter, Charliecloud, Apptainer, Conda) - see below.
 
 > We highly recommend the use of Docker or Singularity containers for full
 > pipeline reproducibility, however when this is not possible, Conda is also supported.
@@ -123,8 +150,10 @@ If `-profile` is not specified, the pipeline will run locally and expect all sof
   - A generic configuration profile to be used with [Shifter](https://nersc.gitlab.io/development/shifter/how-to-use/)
 - `charliecloud`
   - A generic configuration profile to be used with [Charliecloud](https://hpc.github.io/charliecloud/)
+- `apptainer`
+  - A generic configuration profile to be used with [Apptainer](https://apptainer.org/)
 - `conda`
-  - A generic configuration profile to be used with [Conda](https://conda.io/docs/). Please only use Conda as a last resort i.e. when it's not possible to run the pipeline with Docker, Singularity, Podman, Shifter or Charliecloud.
+  - A generic configuration profile to be used with [Conda](https://conda.io/docs/). Please only use Conda as a last resort i.e. when it's not possible to run the pipeline with Docker, Singularity, Podman, Shifter, Charliecloud, or Apptainer.
 
 ### `-resume`
 
@@ -144,102 +173,19 @@ for more information.
 
 Whilst the default requirements set within the pipeline will hopefully work for most people and with most input data, you may find that you want to customise the compute resources that the pipeline requests. Each step in the pipeline has a default set of requirements for number of CPUs, memory and time. For most of the steps in the pipeline, if the job exits with any of the error codes specified [here](https://github.com/nf-core/rnaseq/blob/4c27ef5610c87db00c3c5a3eed10b1d161abf575/conf/base.config#L18) it will automatically be resubmitted with higher requests (2 x original, then 3 x original). If it still fails after the third attempt then the pipeline execution is stopped.
 
-For example, if the nf-core/rnaseq pipeline is failing after multiple re-submissions of the `STAR_ALIGN` process due to an exit code of `137` this would indicate that there is an out of memory issue:
-
-```console
-[62/149eb0] NOTE: Process `NFCORE_RNASEQ:RNASEQ:ALIGN_STAR:STAR_ALIGN (WT_REP1)` terminated with an error exit status (137) -- Execution is retried (1)
-Error executing process > 'NFCORE_RNASEQ:RNASEQ:ALIGN_STAR:STAR_ALIGN (WT_REP1)'
-
-Caused by:
-    Process `NFCORE_RNASEQ:RNASEQ:ALIGN_STAR:STAR_ALIGN (WT_REP1)` terminated with an error exit status (137)
-
-Command executed:
-    STAR \
-        --genomeDir star \
-        --readFilesIn WT_REP1_trimmed.fq.gz  \
-        --runThreadN 2 \
-        --outFileNamePrefix WT_REP1. \
-        <TRUNCATED>
-
-Command exit status:
-    137
-
-Command output:
-    (empty)
-
-Command error:
-    .command.sh: line 9:  30 Killed    STAR --genomeDir star --readFilesIn WT_REP1_trimmed.fq.gz --runThreadN 2 --outFileNamePrefix WT_REP1. <TRUNCATED>
-Work dir:
-    /home/pipelinetest/work/9d/172ca5881234073e8d76f2a19c88fb
-
-Tip: you can replicate the issue by changing to the process work dir and entering the command `bash .command.run`
-```
-
-#### For beginners
-
-A first step to bypass this error, you could try to increase the amount of CPUs, memory, and time for the whole pipeline. Therefor you can try to increase the resource for the parameters `--max_cpus`, `--max_memory`, and `--max_time`. Based on the error above, you have to increase the amount of memory. Therefore you can go to the [parameter documentation of rnaseq](https://nf-co.re/rnaseq/3.9/parameters) and scroll down to the `show hidden parameter` button to get the default value for `--max_memory`. In this case 128GB, you than can try to run your pipeline again with `--max_memory 200GB -resume` to skip all process, that were already calculated. If you can not increase the resource of the complete pipeline, you can try to adapt the resource for a single process as mentioned below.
-
-#### Advanced option on process level
-
-To bypass this error you would need to find exactly which resources are set by the `STAR_ALIGN` process. The quickest way is to search for `process STAR_ALIGN` in the [nf-core/rnaseq Github repo](https://github.com/nf-core/rnaseq/search?q=process+STAR_ALIGN).
-We have standardised the structure of Nextflow DSL2 pipelines such that all module files will be present in the `modules/` directory and so, based on the search results, the file we want is `modules/nf-core/star/align/main.nf`.
-If you click on the link to that file you will notice that there is a `label` directive at the top of the module that is set to [`label process_high`](https://github.com/nf-core/rnaseq/blob/4c27ef5610c87db00c3c5a3eed10b1d161abf575/modules/nf-core/software/star/align/main.nf#L9).
-The [Nextflow `label`](https://www.nextflow.io/docs/latest/process.html#label) directive allows us to organise workflow processes in separate groups which can be referenced in a configuration file to select and configure subset of processes having similar computing requirements.
-The default values for the `process_high` label are set in the pipeline's [`base.config`](https://github.com/nf-core/rnaseq/blob/4c27ef5610c87db00c3c5a3eed10b1d161abf575/conf/base.config#L33-L37) which in this case is defined as 72GB.
-Providing you haven't set any other standard nf-core parameters to **cap** the [maximum resources](https://nf-co.re/usage/configuration#max-resources) used by the pipeline then we can try and bypass the `STAR_ALIGN` process failure by creating a custom config file that sets at least 72GB of memory, in this case increased to 100GB.
-The custom config below can then be provided to the pipeline via the [`-c`](#-c) parameter as highlighted in previous sections.
-
-```nextflow
-process {
-    withName: 'NFCORE_RNASEQ:RNASEQ:ALIGN_STAR:STAR_ALIGN' {
-        memory = 100.GB
-    }
-}
-```
-
-> **NB:** We specify the full process name i.e. `NFCORE_RNASEQ:RNASEQ:ALIGN_STAR:STAR_ALIGN` in the config file because this takes priority over the short name (`STAR_ALIGN`) and allows existing configuration using the full process name to be correctly overridden.
->
-> If you get a warning suggesting that the process selector isn't recognised check that the process name has been specified correctly.
-
-### Updating containers (advanced users)
-
-The [Nextflow DSL2](https://www.nextflow.io/docs/latest/dsl2.html) implementation of this pipeline uses one container per process which makes it much easier to maintain and update software dependencies. If for some reason you need to use a different version of a particular tool with the pipeline then you just need to identify the `process` name and override the Nextflow `container` definition for that process using the `withName` declaration. For example, in the [nf-core/viralrecon](https://nf-co.re/viralrecon) pipeline a tool called [Pangolin](https://github.com/cov-lineages/pangolin) has been used during the COVID-19 pandemic to assign lineages to SARS-CoV-2 genome sequenced samples. Given that the lineage assignments change quite frequently it doesn't make sense to re-release the nf-core/viralrecon everytime a new version of Pangolin has been released. However, you can override the default container used by the pipeline by creating a custom config file and passing it as a command-line argument via `-c custom.config`.
-
-1. Check the default version used by the pipeline in the module file for [Pangolin](https://github.com/nf-core/viralrecon/blob/a85d5969f9025409e3618d6c280ef15ce417df65/modules/nf-core/software/pangolin/main.nf#L14-L19)
-2. Find the latest version of the Biocontainer available on [Quay.io](https://quay.io/repository/biocontainers/pangolin?tag=latest&tab=tags)
-3. Create the custom config accordingly:
-
-   - For Docker:
+To change the resource requests, please see the [max resources](https://nf-co.re/docs/usage/configuration#max-resources) and [tuning workflow resources](https://nf-co.re/docs/usage/configuration#tuning-workflow-resources) section of the nf-core website.
 
-     ```nextflow
-     process {
-         withName: PANGOLIN {
-             container = 'quay.io/biocontainers/pangolin:3.0.5--pyhdfd78af_0'
-         }
-     }
-     ```
+### Custom Containers
 
-   - For Singularity:
+In some cases you may wish to change which container or conda environment a step of the pipeline uses for a particular tool. By default nf-core pipelines use containers and software from the [biocontainers](https://biocontainers.pro/) or [bioconda](https://bioconda.github.io/) projects. However in some cases the pipeline specified version maybe out of date.
 
-     ```nextflow
-     process {
-         withName: PANGOLIN {
-             container = 'https://depot.galaxyproject.org/singularity/pangolin:3.0.5--pyhdfd78af_0'
-         }
-     }
-     ```
+To use a different container from the default container or conda environment specified in a pipeline, please see the [updating tool versions](https://nf-co.re/docs/usage/configuration#updating-tool-versions) section of the nf-core website.
 
-   - For Conda:
+### Custom Tool Arguments
 
-     ```nextflow
-     process {
-         withName: PANGOLIN {
-             conda = 'bioconda::pangolin=3.0.5'
-         }
-     }
-     ```
+A pipeline might not always support every possible argument or option of a particular tool used in pipeline. Fortunately, nf-core pipelines provide some freedom to users to insert additional parameters that the pipeline does not include by default.
 
-> **NB:** If you wish to periodically update individual tool-specific results (e.g. Pangolin) generated by the pipeline then you must ensure to keep the `work/` directory otherwise the `-resume` ability of the pipeline will be compromised and it will restart from scratch.
+To learn how to provide additional arguments to a particular tool of the pipeline, please see the [customising tool arguments](https://nf-co.re/docs/usage/configuration#customising-tool-arguments) section of the nf-core website.
 
 ### nf-core/configs
 
diff --git a/lib/NfcoreSchema.groovy b/lib/NfcoreSchema.groovy
index 33cd4f6e8df62276afa55ab4c00cd59900ea013e..9b34804d6dfd27ce0c723125a9875e23671e4c4a 100755
--- a/lib/NfcoreSchema.groovy
+++ b/lib/NfcoreSchema.groovy
@@ -2,6 +2,7 @@
 // This file holds several functions used to perform JSON parameter validation, help and summary rendering for the nf-core pipeline template.
 //
 
+import nextflow.Nextflow
 import org.everit.json.schema.Schema
 import org.everit.json.schema.loader.SchemaLoader
 import org.everit.json.schema.ValidationException
@@ -83,6 +84,7 @@ class NfcoreSchema {
             'stub-run',
             'test',
             'w',
+            'with-apptainer',
             'with-charliecloud',
             'with-conda',
             'with-dag',
@@ -177,7 +179,7 @@ class NfcoreSchema {
         }
 
         if (has_error) {
-            System.exit(1)
+            Nextflow.error('Exiting!')
         }
     }
 
diff --git a/lib/WorkflowMain.groovy b/lib/WorkflowMain.groovy
index 239d4fe7253d3a060bd99bff6b7842cdeb2891c8..e4bce38300fadf0f573d90304d0ae40606327a3a 100755
--- a/lib/WorkflowMain.groovy
+++ b/lib/WorkflowMain.groovy
@@ -2,6 +2,8 @@
 // This file holds several functions specific to the main.nf workflow in the nf-core/hic pipeline
 //
 
+import nextflow.Nextflow
+
 class WorkflowMain {
 
     //
@@ -20,7 +22,7 @@ class WorkflowMain {
     //
     // Generate help string
     //
-    public static String help(workflow, params, log) {
+    public static String help(workflow, params) {
         def command = "nextflow run ${workflow.manifest.name} --input samplesheet.csv --genome GRCh37 -profile docker"
         def help_string = ''
         help_string += NfcoreTemplate.logo(workflow, params.monochrome_logs)
@@ -33,7 +35,7 @@ class WorkflowMain {
     //
     // Generate parameter summary log string
     //
-    public static String paramsSummaryLog(workflow, params, log) {
+    public static String paramsSummaryLog(workflow, params) {
         def summary_log = ''
         summary_log += NfcoreTemplate.logo(workflow, params.monochrome_logs)
         summary_log += NfcoreSchema.paramsSummaryLog(workflow, params)
@@ -48,7 +50,7 @@ class WorkflowMain {
     public static void initialise(workflow, params, log) {
         // Print help to screen if required
         if (params.help) {
-            log.info help(workflow, params, log)
+            log.info help(workflow, params)
             System.exit(0)
         }
 
@@ -60,7 +62,7 @@ class WorkflowMain {
         }
 
         // Print parameter summary log to screen
-        log.info paramsSummaryLog(workflow, params, log)
+        log.info paramsSummaryLog(workflow, params)
 
         // Validate workflow parameters via the JSON schema
         if (params.validate_params) {
@@ -80,8 +82,7 @@ class WorkflowMain {
 
         // Check input has been provided
         if (!params.input) {
-            log.error "Please provide an input samplesheet to the pipeline e.g. '--input samplesheet.csv'"
-            System.exit(1)
+            Nextflow.error("Please provide an input samplesheet to the pipeline e.g. '--input samplesheet.csv'")
         }
     }
     //
diff --git a/main.nf b/main.nf
index dd564aa4e80652c1a21ba504c0564faddfb74bcd..82aaf0f200b77db6710472f821c715376d2e5668 100644
--- a/main.nf
+++ b/main.nf
@@ -4,7 +4,6 @@
     nf-core/hic
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     Github : https://github.com/nf-core/hic
-
     Website: https://nf-co.re/hic
     Slack  : https://nfcore.slack.com/channels/hic
 ----------------------------------------------------------------------------------------
diff --git a/modules.json b/modules.json
index 45540ca9ea0c4c8493525e58d8671176087348dc..6d7a0306685215f83fe5c69f51f6f54c1927fa04 100644
--- a/modules.json
+++ b/modules.json
@@ -7,52 +7,52 @@
                 "nf-core": {
                     "bowtie2/align": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "603ecbd9f45300c9788f197d2a15a005685b4220",
                         "installed_by": ["modules"]
                     },
                     "bowtie2/build": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "cooler/balance": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "cooler/cload": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "cooler/dump": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "cooler/makebins": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "cooler/zoomify": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "custom/dumpsoftwareversions": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "custom/getchromsizes": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     },
                     "fastqc": {
                         "branch": "master",
-                        "git_sha": "c8e35eb2055c099720a75538d1b8adb3fb5a464c",
+                        "git_sha": "911696ea0b62df80e900ef244d7867d177971f73",
                         "installed_by": ["modules"]
                     }
                 }
diff --git a/modules/local/cooltools/eigscis.nf b/modules/local/cooltools/eigscis.nf
index feaa30007099cae34a18eaa8105a3367e260e1b6..873bd243cd02102f327cba853197d39bc0ea860e 100644
--- a/modules/local/cooltools/eigscis.nf
+++ b/modules/local/cooltools/eigscis.nf
@@ -9,7 +9,7 @@ process COOLTOOLS_EIGSCIS {
     conda "bioconda::cooltools=0.5.1 bioconda::ucsc-bedgraphtobigwig=377"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c81d8d6b6acf4714ffaae1a274527a41958443f6:cc7ea58b8cefc76bed985dcfe261cb276ed9e0cf-0' :
-        'quay.io/biocontainers/mulled-v2-c81d8d6b6acf4714ffaae1a274527a41958443f6:cc7ea58b8cefc76bed985dcfe261cb276ed9e0cf-0' }"
+        'biocontainers/mulled-v2-c81d8d6b6acf4714ffaae1a274527a41958443f6:cc7ea58b8cefc76bed985dcfe261cb276ed9e0cf-0' }"
 
     input:
     tuple val(meta), path(cool), val(resolution)
diff --git a/modules/local/cooltools/insulation.nf b/modules/local/cooltools/insulation.nf
index 8a9127ea47824f9541c4faf2263d8e61030468c3..af53529ef80baa12dbd81bd0a2b8fa3ec2122cfa 100644
--- a/modules/local/cooltools/insulation.nf
+++ b/modules/local/cooltools/insulation.nf
@@ -9,7 +9,7 @@ process COOLTOOLS_INSULATION {
     conda "bioconda::cooltools=0.5.1"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooltools:0.5.1--py37h37892f8_0' :
-        'quay.io/biocontainers/cooltools:0.5.1--py37h37892f8_0' }"
+        'biocontainers/cooltools:0.5.1--py37h37892f8_0' }"
 
     input:
     tuple val(meta), path(cool)
diff --git a/modules/local/hicexplorer/hicFindTADs.nf b/modules/local/hicexplorer/hicFindTADs.nf
index b6cae335c22111407b3d782e95a067ed087645e0..d86dc837e29e56aa4ba88cd2c66962444046647b 100644
--- a/modules/local/hicexplorer/hicFindTADs.nf
+++ b/modules/local/hicexplorer/hicFindTADs.nf
@@ -8,7 +8,7 @@ process HIC_FIND_TADS {
     conda "bioconda::hicexplorer=3.7.2"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/hicexplorer:3.7.2--pyhdfd78af_1' :
-        'quay.io/biocontainers/hicexplorer:3.7.2--pyhdfd78af_1' }"
+        'biocontainers/hicexplorer:3.7.2--pyhdfd78af_1' }"
 
     input:
     tuple val(meta), path(cool)
diff --git a/modules/local/hicexplorer/hicPlotDistVsCounts.nf b/modules/local/hicexplorer/hicPlotDistVsCounts.nf
index 3e37d3fe7b466dbe45b2f19c220e2f9a65a07a9a..1143a05d3767ba4a9289e6f423cb7dc768d3d197 100644
--- a/modules/local/hicexplorer/hicPlotDistVsCounts.nf
+++ b/modules/local/hicexplorer/hicPlotDistVsCounts.nf
@@ -9,7 +9,7 @@ process HIC_PLOT_DIST_VS_COUNTS {
     conda "bioconda::hicexplorer=3.7.2"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/hicexplorer:3.7.2--pyhdfd78af_1' :
-        'quay.io/biocontainers/hicexplorer:3.7.2--pyhdfd78af_1' }"
+        'biocontainers/hicexplorer:3.7.2--pyhdfd78af_1' }"
 
     input:
     tuple val(meta), path(cool)
diff --git a/modules/local/hicpro/bowtie2_merge.nf b/modules/local/hicpro/bowtie2_merge.nf
index 7a4e96be9aaf2470a10ca19672591e0f84853602..64aa6e6c05fd9e729ac26a0704f33b802f7dbb0c 100644
--- a/modules/local/hicpro/bowtie2_merge.nf
+++ b/modules/local/hicpro/bowtie2_merge.nf
@@ -5,7 +5,7 @@ process MERGE_BOWTIE2{
     conda "bioconda::samtools=1.15.1"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/samtools:1.15.1--h1170115_0' :
-        'quay.io/biocontainers/samtools:1.15.1--h1170115_0' }"
+        'biocontainers/samtools:1.15.1--h1170115_0' }"
 
     input:
     tuple val(meta), path(bam1), path(bam2)
diff --git a/modules/local/hicpro/build_contact_maps.nf b/modules/local/hicpro/build_contact_maps.nf
index fd633a984f26b4cccc901a92e983cf0acfaa8eed..271913ec49b1d362b6b0fb065506961d85ad82fc 100644
--- a/modules/local/hicpro/build_contact_maps.nf
+++ b/modules/local/hicpro/build_contact_maps.nf
@@ -1,27 +1,27 @@
 process BUILD_CONTACT_MAPS{
-  tag "${meta.id}"
-  label 'process_high_memory'
+    tag "${meta.id}"
+    label 'process_high_memory'
 
-  conda "conda-forge::sed=4.7"
-  container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
-      'https://depot.galaxyproject.org/singularity/ubuntu:20.04' :
-      'ubuntu:20.04' }"
+    conda "conda-forge::sed=4.7"
+    container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
+        'https://depot.galaxyproject.org/singularity/ubuntu:20.04' :
+        'nf-core/ubuntu:20.04' }"
 
-  input:
-  tuple val(meta), path(vpairs), val(resolution) 
-  tuple val(meta2), path(chrsize) 
+    input:
+    tuple val(meta), path(vpairs), val(resolution)
+    tuple val(meta2), path(chrsize)
 
-  output:
-  tuple val(meta), val(resolution), path("*.matrix"), path("*.bed"), emit: maps
-   
-  script:
-  def prefix = task.ext.prefix ?: "${meta.id}"
-  """
-  build_matrix \\
-    --matrix-format upper  \\
-    --binsize ${resolution} \\
-    --chrsizes ${chrsize} \\
-    --ifile ${vpairs} \\
-    --oprefix ${prefix}
-  """
+    output:
+    tuple val(meta), val(resolution), path("*.matrix"), path("*.bed"), emit: maps
+
+    script:
+    def prefix = task.ext.prefix ?: "${meta.id}"
+    """
+    build_matrix \\
+        --matrix-format upper  \\
+        --binsize ${resolution} \\
+        --chrsizes ${chrsize} \\
+        --ifile ${vpairs} \\
+        --oprefix ${prefix}
+    """
 }
diff --git a/modules/local/hicpro/combine_mates.nf b/modules/local/hicpro/combine_mates.nf
index da95be819a03560d75db2bc80ab3e8b72bf774aa..1f31e66c50656f5c52a5e802aa53cb25bd39c05f 100644
--- a/modules/local/hicpro/combine_mates.nf
+++ b/modules/local/hicpro/combine_mates.nf
@@ -5,7 +5,7 @@ process COMBINE_MATES {
     conda "conda-forge::python=3.9  bioconda::pysam=0.19.0"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), path(bam)
diff --git a/modules/local/hicpro/dnase_mapping_stats.nf b/modules/local/hicpro/dnase_mapping_stats.nf
index 64cb0792e4d93dfcc1b1e7d0b5d50bf7e0b75c73..8e85113944f79dc0b155ee9be441b2badf5c0245 100644
--- a/modules/local/hicpro/dnase_mapping_stats.nf
+++ b/modules/local/hicpro/dnase_mapping_stats.nf
@@ -5,7 +5,7 @@ process MAPPING_STATS_DNASE {
     conda "bioconda::samtools=1.15.1"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/samtools:1.15.1--h1170115_0' :
-        'quay.io/biocontainers/samtools:1.15.1--h1170115_0' }"
+        'biocontainers/samtools:1.15.1--h1170115_0' }"
 
 
     input:
diff --git a/modules/local/hicpro/get_restriction_fragments.nf b/modules/local/hicpro/get_restriction_fragments.nf
index affc2d986a339d239602c6e66ad6f0d50517505e..d810c4cbb96f9be1a5cb43602e5b891787ef4356 100644
--- a/modules/local/hicpro/get_restriction_fragments.nf
+++ b/modules/local/hicpro/get_restriction_fragments.nf
@@ -5,7 +5,7 @@ process GET_RESTRICTION_FRAGMENTS {
     conda "conda-forge::python=3.9 conda-forge::numpy=1.22.3"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), path(fasta)
diff --git a/modules/local/hicpro/get_valid_interaction.nf b/modules/local/hicpro/get_valid_interaction.nf
index cc148371e52e04e96ca8dc9461a46ce80216b85e..a093977d44187e83627b8e8244127b2a71bdc837 100644
--- a/modules/local/hicpro/get_valid_interaction.nf
+++ b/modules/local/hicpro/get_valid_interaction.nf
@@ -5,7 +5,7 @@ process GET_VALID_INTERACTION {
     conda "conda-forge::python=3.9  bioconda::pysam=0.19.0 bioconda::bx-python=0.8.13"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), path(bam)
diff --git a/modules/local/hicpro/get_valid_interaction_dnase.nf b/modules/local/hicpro/get_valid_interaction_dnase.nf
index 142d0cbd4f042fb0106c7e0380515f7b54c79953..6bb841eeb470e2cfe43d40896d58013789fdc610 100644
--- a/modules/local/hicpro/get_valid_interaction_dnase.nf
+++ b/modules/local/hicpro/get_valid_interaction_dnase.nf
@@ -5,7 +5,7 @@ process GET_VALID_INTERACTION_DNASE {
     conda "conda-forge::python=3.9 bioconda::pysam=0.19.0 bioconda::bx-python=0.8.13"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), path(bam)
diff --git a/modules/local/hicpro/hicpro2pairs.nf b/modules/local/hicpro/hicpro2pairs.nf
index 2ba2a901b62791e733900b24da4f244cd2fbaba7..eb9b86b5e4ca0ace6549fe0c33a9dd1f63aaf5f3 100644
--- a/modules/local/hicpro/hicpro2pairs.nf
+++ b/modules/local/hicpro/hicpro2pairs.nf
@@ -5,7 +5,7 @@ process HICPRO2PAIRS {
     conda "bioconda::pairix=0.3.7"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/pairix:0.3.7--py36h30a8e3e_3' :
-        'quay.io/biocontainers/pairix:0.3.7--py36h30a8e3e_3' }"
+        'biocontainers/pairix:0.3.7--py36h30a8e3e_3' }"
 
     input:
     tuple val(meta), path(vpairs)
diff --git a/modules/local/hicpro/merge_stats.nf b/modules/local/hicpro/merge_stats.nf
index b25dc8a13d2f18bc5ae05742c5f15d77fd19627d..eb9a9e02f27844bff1698f1255726866e3f84290 100644
--- a/modules/local/hicpro/merge_stats.nf
+++ b/modules/local/hicpro/merge_stats.nf
@@ -5,7 +5,7 @@ process MERGE_STATS {
     conda "conda-forge::python=3.9"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), path(fstat)
diff --git a/modules/local/hicpro/merge_valid_interaction.nf b/modules/local/hicpro/merge_valid_interaction.nf
index 29e568a20997c0a313a87cf964f1f8c10327228b..2dcb63d176704a97fcb87fa3cf391f6ec9f5888d 100644
--- a/modules/local/hicpro/merge_valid_interaction.nf
+++ b/modules/local/hicpro/merge_valid_interaction.nf
@@ -5,7 +5,7 @@ process MERGE_VALID_INTERACTION {
     conda "conda-forge::gawk=5.1.0"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/ubuntu:20.04' :
-        'ubuntu:20.04' }"
+        'nf-core/ubuntu:20.04' }"
 
     input:
     tuple val(meta), path(vpairs)
diff --git a/modules/local/hicpro/run_ice.nf b/modules/local/hicpro/run_ice.nf
index 0a435edcd0f2a82c93be2a1b9bd832a721c270cf..7ef5727378fdfabfb7b93e2852c11131481c0a11 100644
--- a/modules/local/hicpro/run_ice.nf
+++ b/modules/local/hicpro/run_ice.nf
@@ -1,11 +1,11 @@
-process ICE_NORMALIZATION{
+process ICE_NORMALIZATION {
     tag "$meta.id"
     label 'process_high_memory'
 
     conda "conda-forge::python=3.9 bioconda::iced=0.5.10 conda-forge::numpy=1.22.3"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' :
-        'quay.io/biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0'}"
+        'biocontainers/mulled-v2-c6ff206325681cbb9c9ef890bb8de554172c0483:713df51cd897ceb893b9a6e6420f527d83c2ed95-0' }"
 
     input:
     tuple val(meta), val(res), path(rmaps), path(bed)
diff --git a/modules/local/hicpro/trim_reads.nf b/modules/local/hicpro/trim_reads.nf
index 5a96df412ea89845583fc363eccf2df49ba9458d..b28d4930a21f5af2b84b435ef3ba53575f31d7bc 100644
--- a/modules/local/hicpro/trim_reads.nf
+++ b/modules/local/hicpro/trim_reads.nf
@@ -5,7 +5,7 @@ process TRIM_READS {
     conda "conda-forge::sed=4.7"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/ubuntu:20.04' :
-        'ubuntu:20.04' }"
+        'nf-core/ubuntu:20.04' }"
 
     input:
     tuple val(meta), path(reads)
diff --git a/modules/local/multiqc.nf b/modules/local/multiqc.nf
index 595dc94d0eebd849d217c25349e4bb253bee64b6..453513fbd586e81e0c069f8029339d37f87c75c3 100644
--- a/modules/local/multiqc.nf
+++ b/modules/local/multiqc.nf
@@ -1,10 +1,10 @@
 process MULTIQC {
     label 'process_medium'
 
-    conda "bioconda::multiqc=1.13"
+    conda "bioconda::multiqc=1.14"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
-        'https://depot.galaxyproject.org/singularity/multiqc:1.13--pyhdfd78af_0' :
-        'quay.io/biocontainers/multiqc:1.13--pyhdfd78af_0' }"
+        'https://depot.galaxyproject.org/singularity/multiqc:1.14--pyhdfd78af_0' :
+        'biocontainers/multiqc:1.14--pyhdfd78af_0' }"
 
     input:
     path multiqc_config
diff --git a/modules/local/samplesheet_check.nf b/modules/local/samplesheet_check.nf
index 1624dfafe6425f07bbd15daf3b2735ea1187c0ec..096c80b0bd37b9a40bbf61cdefa13007f58b0c5d 100644
--- a/modules/local/samplesheet_check.nf
+++ b/modules/local/samplesheet_check.nf
@@ -5,7 +5,7 @@ process SAMPLESHEET_CHECK {
     conda "conda-forge::python=3.8.3"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/python:3.8.3' :
-        'quay.io/biocontainers/python:3.8.3' }"
+        'biocontainers/python:3.8.3' }"
 
     input:
     path samplesheet
diff --git a/modules/local/split_cooler_dump.nf b/modules/local/split_cooler_dump.nf
index 8b9e45b31d304545ea62946f4c4e0eacb7860002..b2f9610fcf55558abd0d815a1e4c56e81b772d4f 100644
--- a/modules/local/split_cooler_dump.nf
+++ b/modules/local/split_cooler_dump.nf
@@ -5,7 +5,7 @@ process SPLIT_COOLER_DUMP {
     conda "conda-forge::gawk=5.1.0"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/ubuntu:20.04' :
-        'ubuntu:20.04' }"
+        'nf-core/ubuntu:20.04' }"
 
     input:
     tuple val(meta), path(bedpe)
diff --git a/modules/nf-core/bowtie2/align/main.nf b/modules/nf-core/bowtie2/align/main.nf
index 3d851866a30b4f629881864516f0789f6cae9443..311a1505eccdd3825db6ad8652305cb445148ae3 100644
--- a/modules/nf-core/bowtie2/align/main.nf
+++ b/modules/nf-core/bowtie2/align/main.nf
@@ -5,7 +5,7 @@ process BOWTIE2_ALIGN {
     conda "bioconda::bowtie2=2.4.4 bioconda::samtools=1.16.1 conda-forge::pigz=2.6"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/mulled-v2-ac74a7f02cebcfcc07d8e8d1d750af9c83b4d45a:a0ffedb52808e102887f6ce600d092675bf3528a-0' :
-        'quay.io/biocontainers/mulled-v2-ac74a7f02cebcfcc07d8e8d1d750af9c83b4d45a:a0ffedb52808e102887f6ce600d092675bf3528a-0' }"
+        'biocontainers/mulled-v2-ac74a7f02cebcfcc07d8e8d1d750af9c83b4d45a:a0ffedb52808e102887f6ce600d092675bf3528a-0' }"
 
     input:
     tuple val(meta) , path(reads)
diff --git a/modules/nf-core/bowtie2/build/main.nf b/modules/nf-core/bowtie2/build/main.nf
index 551893af3b3bb1a3955f1cc7c0b50735c6fded8d..566a4accda99ed7c9c56564f6c3348bec439df11 100644
--- a/modules/nf-core/bowtie2/build/main.nf
+++ b/modules/nf-core/bowtie2/build/main.nf
@@ -5,7 +5,7 @@ process BOWTIE2_BUILD {
     conda "bioconda::bowtie2=2.4.4"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/bowtie2:2.4.4--py39hbb4e92a_0' :
-        'quay.io/biocontainers/bowtie2:2.4.4--py39hbb4e92a_0' }"
+        'biocontainers/bowtie2:2.4.4--py39hbb4e92a_0' }"
 
     input:
     tuple val(meta), path(fasta)
diff --git a/modules/nf-core/cooler/balance/main.nf b/modules/nf-core/cooler/balance/main.nf
index 4173a3c1291df7e25e3529d9ab8f2b6f8d1240b7..6e131d5b4717de6a6e7079b067154f7dd7e4e937 100644
--- a/modules/nf-core/cooler/balance/main.nf
+++ b/modules/nf-core/cooler/balance/main.nf
@@ -5,7 +5,7 @@ process COOLER_BALANCE {
     conda "bioconda::cooler=0.8.11"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooler:0.8.11--pyh3252c3a_0':
-        'quay.io/biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
+        'biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
 
     input:
     tuple val(meta), path(cool), val(resolution)
diff --git a/modules/nf-core/cooler/cload/main.nf b/modules/nf-core/cooler/cload/main.nf
index 80d61f07336f81233a6bd8ffb116e5a25e57048d..80109d48f449af278016bbda6cd08c46bbf8e183 100644
--- a/modules/nf-core/cooler/cload/main.nf
+++ b/modules/nf-core/cooler/cload/main.nf
@@ -5,7 +5,7 @@ process COOLER_CLOAD {
     conda "bioconda::cooler=0.8.11"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooler:0.8.11--pyh3252c3a_0' :
-        'quay.io/biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
+        'biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
 
     input:
     tuple val(meta), path(pairs), path(index), val(cool_bin)
diff --git a/modules/nf-core/cooler/dump/main.nf b/modules/nf-core/cooler/dump/main.nf
index b46c78cf35ec6b40276e2d792635f97b9909ab55..fed7502f8cb6a788b056c87aab3a2e71d26dd400 100644
--- a/modules/nf-core/cooler/dump/main.nf
+++ b/modules/nf-core/cooler/dump/main.nf
@@ -5,7 +5,7 @@ process COOLER_DUMP {
     conda "bioconda::cooler=0.8.11"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooler:0.8.11--pyh3252c3a_0' :
-        'quay.io/biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
+        'biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
 
     input:
     tuple val(meta), path(cool), val(resolution)
diff --git a/modules/nf-core/cooler/makebins/main.nf b/modules/nf-core/cooler/makebins/main.nf
index 7f0826197e99e9e79107359a8c65d7d60346dc49..25d6a40f636257c90251893c74eb2769200b41c1 100644
--- a/modules/nf-core/cooler/makebins/main.nf
+++ b/modules/nf-core/cooler/makebins/main.nf
@@ -5,7 +5,7 @@ process COOLER_MAKEBINS {
     conda "bioconda::cooler=0.8.11"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooler:0.8.11--pyh3252c3a_0':
-        'quay.io/biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
+        'biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
 
     input:
     tuple val(meta), path(chromsizes), val(cool_bin)
diff --git a/modules/nf-core/cooler/zoomify/main.nf b/modules/nf-core/cooler/zoomify/main.nf
index f1cd8df79d02b8630c31de0620521cef0cdd6df0..95e7daff0d19429507d01033eb78eba491625220 100644
--- a/modules/nf-core/cooler/zoomify/main.nf
+++ b/modules/nf-core/cooler/zoomify/main.nf
@@ -5,7 +5,7 @@ process COOLER_ZOOMIFY {
     conda "bioconda::cooler=0.8.11"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/cooler:0.8.11--pyh3252c3a_0' :
-        'quay.io/biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
+        'biocontainers/cooler:0.8.11--pyh3252c3a_0' }"
 
     input:
     tuple val(meta), path(cool)
diff --git a/modules/nf-core/custom/dumpsoftwareversions/main.nf b/modules/nf-core/custom/dumpsoftwareversions/main.nf
index 3df21765b90921413962c3bb5ca44d117d829297..ebc8727339b0ee4ce7e2feb981a0aaf416723b57 100644
--- a/modules/nf-core/custom/dumpsoftwareversions/main.nf
+++ b/modules/nf-core/custom/dumpsoftwareversions/main.nf
@@ -2,10 +2,10 @@ process CUSTOM_DUMPSOFTWAREVERSIONS {
     label 'process_single'
 
     // Requires `pyyaml` which does not have a dedicated container but is in the MultiQC container
-    conda "bioconda::multiqc=1.13"
+    conda "bioconda::multiqc=1.14"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
-        'https://depot.galaxyproject.org/singularity/multiqc:1.13--pyhdfd78af_0' :
-        'quay.io/biocontainers/multiqc:1.13--pyhdfd78af_0' }"
+        'https://depot.galaxyproject.org/singularity/multiqc:1.14--pyhdfd78af_0' :
+        'biocontainers/multiqc:1.14--pyhdfd78af_0' }"
 
     input:
     path versions
diff --git a/modules/nf-core/custom/dumpsoftwareversions/meta.yml b/modules/nf-core/custom/dumpsoftwareversions/meta.yml
index 60b546a012c457b5459490e732e6ac9be6979db1..c32657de7a2c09e82da1e753a234300fb76237ed 100644
--- a/modules/nf-core/custom/dumpsoftwareversions/meta.yml
+++ b/modules/nf-core/custom/dumpsoftwareversions/meta.yml
@@ -1,7 +1,9 @@
+# yaml-language-server: $schema=https://raw.githubusercontent.com/nf-core/modules/master/modules/yaml-schema.json
 name: custom_dumpsoftwareversions
 description: Custom module used to dump software versions within the nf-core pipeline template
 keywords:
   - custom
+  - dump
   - version
 tools:
   - custom:
diff --git a/modules/nf-core/custom/dumpsoftwareversions/templates/dumpsoftwareversions.py b/modules/nf-core/custom/dumpsoftwareversions/templates/dumpsoftwareversions.py
index b83b32c4d4242764a439f4d51e0255711f9cd40f..da03340857c4c90957c79c9f892030bc1bb397a3 100755
--- a/modules/nf-core/custom/dumpsoftwareversions/templates/dumpsoftwareversions.py
+++ b/modules/nf-core/custom/dumpsoftwareversions/templates/dumpsoftwareversions.py
@@ -3,10 +3,10 @@
 
 """Provide functions to merge multiple versions.yml files."""
 
-import platform
-from textwrap import dedent
 
 import yaml
+import platform
+from textwrap import dedent
 
 
 def _make_versions_html(versions):
diff --git a/modules/nf-core/custom/getchromsizes/main.nf b/modules/nf-core/custom/getchromsizes/main.nf
index 580f87feade7280bb8d520551aa61f0021b3b88d..060a2e88527af75fabb1d87858c2885b6ca09547 100644
--- a/modules/nf-core/custom/getchromsizes/main.nf
+++ b/modules/nf-core/custom/getchromsizes/main.nf
@@ -5,7 +5,7 @@ process CUSTOM_GETCHROMSIZES {
     conda "bioconda::samtools=1.16.1"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/samtools:1.16.1--h6899075_1' :
-        'quay.io/biocontainers/samtools:1.16.1--h6899075_1' }"
+        'biocontainers/samtools:1.16.1--h6899075_1' }"
 
     input:
     tuple val(meta), path(fasta)
diff --git a/modules/nf-core/fastqc/main.nf b/modules/nf-core/fastqc/main.nf
index 9ae5838158b28d2ae49270133fbbfe0ea673e991..07d5e433128b416714860fe1dca659219ba1d1ad 100644
--- a/modules/nf-core/fastqc/main.nf
+++ b/modules/nf-core/fastqc/main.nf
@@ -5,7 +5,7 @@ process FASTQC {
     conda "bioconda::fastqc=0.11.9"
     container "${ workflow.containerEngine == 'singularity' && !task.ext.singularity_pull_docker_container ?
         'https://depot.galaxyproject.org/singularity/fastqc:0.11.9--0' :
-        'quay.io/biocontainers/fastqc:0.11.9--0' }"
+        'biocontainers/fastqc:0.11.9--0' }"
 
     input:
     tuple val(meta), path(reads)
diff --git a/nextflow.config b/nextflow.config
index 4513d65e9e615b858a5bc683fa983fb4503e7be2..24d1bc0e535fa7c8bc48fb93ce22e9875a12c716 100644
--- a/nextflow.config
+++ b/nextflow.config
@@ -54,13 +54,13 @@ params {
          ligation_site='GATCGATC,GATCANTC,GANTGATC,GANTANTC'
       }
     }
-    
+
     min_restriction_fragment_size = 0
     max_restriction_fragment_size = 0
     min_insert_size = 0
     max_insert_size = 0
     save_pairs_intermediates = false
-   
+
     // Dnase Hi-C
     dnase = false
     min_cis_dist = 0
@@ -111,7 +111,7 @@ params {
     validate_params            = true
     show_hidden_params         = false
     schema_ignore_params       = 'genomes,digest'
- 
+
     // Config options
     custom_config_version      = 'master'
     custom_config_base         = "https://raw.githubusercontent.com/nf-core/configs/${params.custom_config_version}"
@@ -152,7 +152,11 @@ try {
 
 
 profiles {
-    debug { process.beforeScript = 'echo $HOSTNAME' }
+    debug {
+        dumpHashes             = true
+        process.beforeScript   = 'echo $HOSTNAME'
+        cleanup = false
+    }
     conda {
         conda.enabled          = true
         docker.enabled         = false
@@ -160,6 +164,7 @@ profiles {
         podman.enabled         = false
         shifter.enabled        = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     mamba {
         conda.enabled          = true
@@ -169,14 +174,18 @@ profiles {
         podman.enabled         = false
         shifter.enabled        = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     docker {
         docker.enabled         = true
+        docker.registry        = 'quay.io'
         docker.userEmulation   = true
+        conda.enabled          = false
         singularity.enabled    = false
         podman.enabled         = false
         shifter.enabled        = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     arm {
         docker.runOptions = '-u $(id -u):$(id -g) --platform=linux/amd64'
@@ -184,37 +193,58 @@ profiles {
     singularity {
         singularity.enabled    = true
         singularity.autoMounts = true
+        conda.enabled          = false
         docker.enabled         = false
         podman.enabled         = false
         shifter.enabled        = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     podman {
         podman.enabled         = true
+        podman.registry        = 'quay.io'
+        conda.enabled          = false
         docker.enabled         = false
         singularity.enabled    = false
         shifter.enabled        = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     shifter {
         shifter.enabled        = true
+        conda.enabled          = false
         docker.enabled         = false
         singularity.enabled    = false
         podman.enabled         = false
         charliecloud.enabled   = false
+        apptainer.enabled      = false
     }
     charliecloud {
         charliecloud.enabled   = true
+        conda.enabled          = false
+        docker.enabled         = false
+        singularity.enabled    = false
+        podman.enabled         = false
+        shifter.enabled        = false
+        apptainer.enabled      = false
+    }
+    apptainer {
+        apptainer.enabled      = true
+        conda.enabled          = false
         docker.enabled         = false
         singularity.enabled    = false
         podman.enabled         = false
         shifter.enabled        = false
+        charliecloud.enabled   = false
     }
     gitpod {
         executor.name          = 'local'
         executor.cpus          = 16
         executor.memory        = 60.GB
     }
+    public_aws_ecr {
+        includeConfig 'conf/public_aws_ecr.config'
+    }
     test      { includeConfig 'conf/test.config'      }
     test_full { includeConfig 'conf/test_full.config' }
 }
@@ -242,6 +272,12 @@ env {
 // Capture exit codes from upstream processes when piping
 process.shell = ['/bin/bash', '-euo', 'pipefail']
 
+// Set default registry for Docker and Podman independent of -profile
+// Will not be used unless Docker / Podman are enabled
+// Set to your registry if you have a mirror of containers
+docker.registry = 'quay.io'
+podman.registry = 'quay.io'
+
 def trace_timestamp = new java.util.Date().format( 'yyyy-MM-dd_HH-mm-ss')
 timeline {
     enabled = true
@@ -267,7 +303,7 @@ manifest {
     description     = """Analysis of Chromosome Conformation Capture data (Hi-C)"""
     mainScript      = 'main.nf'
     nextflowVersion = '!>=22.10.1'
-    version = '2.0.0'
+    version         = '2.1.0'
     doi             = ''
 }
 
diff --git a/tower.yml b/tower.yml
new file mode 100644
index 0000000000000000000000000000000000000000..787aedfe920c803b6733a8c8a8bafd585e73a264
--- /dev/null
+++ b/tower.yml
@@ -0,0 +1,5 @@
+reports:
+  multiqc_report.html:
+    display: "MultiQC HTML report"
+  samplesheet.csv:
+    display: "Auto-created samplesheet with collated metadata and FASTQ paths"
diff --git a/workflows/hic.nf b/workflows/hic.nf
index fed1114320cbc615259ab66db847887f9eef100d..2ffa5b4dc8bee033473cab5b755befe9460ca0a9 100644
--- a/workflows/hic.nf
+++ b/workflows/hic.nf
@@ -28,6 +28,9 @@ if (params.digestion){
   ch_restriction_site = Channel.value(restriction_site)
   ligation_site = params.digestion ? params.digest[ params.digestion ].ligation_site ?: false : false
   ch_ligation_site = Channel.value(ligation_site)
+}else if (params.restriction_site && params.ligation_site){
+  ch_restriction_site = Channel.value(params.restriction_site)
+  ch_ligation_site = Channel.value(params.ligation_site)
 }else if (params.dnase){
   ch_restriction_site = Channel.empty()
   ch_ligation_site = Channel.empty()
diff --git a/lib/WorkflowHic.groovy b/lib/WorkflowHic.groovy
index 3dea732db2bb9c05d5002920297d8d727efea9d0..f14c26c5b91565eeca44afa6d51e3442e213bf16 100755
--- a/lib/WorkflowHic.groovy
+++ b/lib/WorkflowHic.groovy
@@ -2,6 +2,7 @@
 // This file holds several functions specific to the workflow/hic.nf in the nf-core/hic pipeline
 //
 
+import nextflow.Nextflow
 import groovy.text.SimpleTemplateEngine
 
 class WorkflowHic {
@@ -14,14 +15,12 @@ class WorkflowHic {
 
         // digestion parameters
         if (params.digest && params.digestion && !params.digest.containsKey(params.digestion)) {
-            log.error "Unknown digestion protocol. Currently, the available digestion options are ${params.digest.keySet().join(", ")}. Please set manually the '--restriction_site' and '--ligation_site' parameters."
-            System.exit(1)
+            Nextflow.error "Unknown digestion protocol. Currently, the available digestion options are ${params.digest.keySet().join(", ")}. Please set manually the '--restriction_site' and '--ligation_site' parameters."
         }
 
         // Check Digestion or DNase Hi-C mode
         //if (!params.dnase && !params.ligation_site) {
         //  log.error "Ligation motif not found. Please either use the `--digestion` parameters or specify the `--restriction_site` and `--ligation_site`. For DNase Hi-C, please use '--dnase' option"
         //  System.exit(1)
         //}
 
     }
@@ -68,17 +67,19 @@ class WorkflowHic {
         def description_html = engine.createTemplate(methods_text).make(meta)
 
         return description_html
-    }//
+    }
+
+    //
     // Exit pipeline if incorrect --genome key provided
     //
     private static void genomeExistsError(params, log) {
         if (params.genomes && params.genome && !params.genomes.containsKey(params.genome)) {
-            log.error "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n" +
+            def error_string = "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n" +
                 "  Genome '${params.genome}' not found in any config files provided to the pipeline.\n" +
                 "  Currently, the available genome keys are:\n" +
                 "  ${params.genomes.keySet().join(", ")}\n" +
                 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
-            System.exit(1)
+            Nextflow.error(error_string)
         }
     }
 }
@@ -14,14 +15,12 @@ class WorkflowHic {
         // Check Digestion or DNase Hi-C mode
         //if (!params.dnase && !params.ligation_site) {
-        //  log.error "Ligation motif not found. Please either use the `--digestion` parameters or specify the `--restriction_site` and `--ligation_site`. For DNase Hi-C, please use '--dnase' option"
-        //  System.exit(1)
+        //  Nextflow.error "Ligation motif not found. Please either use the `--digestion` parameters or specify the `--restriction_site` and `--ligation_site`. For DNase Hi-C, please use '--dnase' option"
         //}
 